@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use POE qw(Wheel::FollowTail);
 use Log::Syslog::Fast ':all';
-use Sys::Hostname;
+use Sys::Hostname qw( hostname );
 
 =head1 NAME
 
@@ -13,11 +13,11 @@ File::Syslogger - Use POE to tail a file and read new lines into syslog.
 
 =head1 VERSION
 
-Version 0.0.2
+Version 0.0.3
 
 =cut
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 =head1 SYNOPSIS
 
@@ -42,17 +42,17 @@ This will die if there are any config issues.
 
 The following options are optionaal.
 
-    priority - The priority of the logged item.
-          Default is 'notice'.
-    
-    facility - The facility for logging.
-               Default is 'daemon'.
-    
-    program - Name of the program logging.
-              Default is 'fileSyslogger'.
-    
-    socket - The syslogd socket.
-             Default is "/var/run/log"
+    - priority :: The priority of the logged item.
+          Default :: notice
+
+    - facility :: The facility for logging.
+          Default :: daemon
+
+    - program :: Name of the program logging.
+          Default :: fileSyslogger
+
+    - socket :: The syslogd socket.
+        Default :: /var/run/log
 
 The option files is a hash of hashes. It has one mandatory
 key, 'file', which is the file to follow. All the above
@@ -113,8 +113,8 @@ sub run {
 		$opts{program} = 'fileSyslogger';
 	}
 
-	if (!defined( $opts{socket} )) {
-		$opts{socket}="/var/run/log";
+	if ( !defined( $opts{socket} ) ) {
+		$opts{socket} = "/var/run/log";
 	}
 
 	#mapping for severity for constant handling
@@ -134,8 +134,7 @@ sub run {
 	# default to info if none is specified
 	if ( !defined( $opts{priority} ) ) {
 		$opts{priority} = "notice";
-	}
-	else {
+	} else {
 		# one was specified, convert to lower case and make sure it valid
 		$opts{priority} = lc( $opts{priority} );
 		if ( !defined( $sev_mapping{ $opts{priority} } ) ) {
@@ -170,8 +169,7 @@ sub run {
 	# default to system if none is specified
 	if ( !defined( $opts{facility} ) ) {
 		$opts{facility} = 'daemon';
-	}
-	else {
+	} else {
 		# one was specified, convert to lower case and make sure it valid
 		$opts{facility} = lc( $opts{facility} );
 		if ( !defined( $fac_mapping{ $opts{facility} } ) ) {
@@ -197,12 +195,11 @@ sub run {
 			if ( !defined( $fac_mapping{ $opts{facility} } ) ) {
 				die( '"' . $item_fac . '" in "' . $item . '" is not a known facility' );
 			}
-		}
-		else {
+		} else {
 			# none specified, so using default
 			$item_fac = $opts{facility};
 		}
-		$item_fac=$fac_mapping{$item_fac};
+		$item_fac = $fac_mapping{$item_fac};
 
 		# figure out what facility to use for this item
 		my $item_pri;
@@ -213,25 +210,24 @@ sub run {
 			if ( !defined( $fac_mapping{$item_pri} ) ) {
 				die( '"' . $item_pri . '" in "' . $item . '" is not a known facility' );
 			}
-		}
-		else {
+		} else {
 			# none specified, so using default
 			$item_pri = $opts{priority};
 		}
-		$item_pri=$sev_mapping{$item_pri};
+		$item_pri = $sev_mapping{$item_pri};
 
 		# figure out what program name to use
 		my $item_program;
 		if ( defined( $opts{files}{$item}{program} ) ) {
 			$item_program = $opts{files}{$item}{program};
-		}
-		else {
+		} else {
 			# none specified, so using default
 			$item_program = $opts{program};
 		}
 
 		# create the logger that will be used by the POE session
-		my $logger = Log::Syslog::Fast->new( LOG_UNIX, $opts{socket}, 1, $item_fac, $item_pri, hostname, $item_program );
+		my $logger
+			= Log::Syslog::Fast->new( LOG_UNIX, $opts{socket}, 1, $item_fac, $item_pri, hostname, $item_program );
 
 		# create the POE session
 		POE::Session->create(
@@ -250,14 +246,14 @@ sub run {
 		);
 
 		$file_count++;
-	}
+	} ## end foreach my $item ( keys( %{ $opts{files} } ) )
 
 	if ( $file_count == 0 ) {
 		die("No files specified");
 	}
 
 	POE::Kernel->run;
-}
+} ## end sub run
 
 =head1 AUTHOR
 
@@ -269,8 +265,7 @@ Please report any bugs or feature requests to C<bug-file-syslogger at rt.cpan.or
 the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Syslogger>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
+Or via Github at L<https://github.com/VVelox/File-Syslogger/issues>.
 
 =head1 SUPPORT
 
@@ -283,14 +278,14 @@ You can also look for information at:
 
 =over 4
 
+=item * GitHub
+
+L<https://github.com/VVelox/File-Syslogger>
+
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Syslogger>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/File-Syslogger>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/File-Syslogger>
@@ -303,7 +298,7 @@ L<https://metacpan.org/release/File-Syslogger>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2021 by Zane C. Bowers-Hadley.
+This software is Copyright (c) 2025 by Zane C. Bowers-Hadley.
 
 This is free software, licensed under:
 
